/**
 * GitDocumentDB plugin for remote connection using NodeGit
 * Copyright (c) Hidekazu Kubota
 *
 * This source code is licensed under the Mozilla Public License Version 2.0
 * found in the LICENSE file in the root directory of this source tree.
 */
import { Logger } from 'tslog';
import { RemoteOptions } from './types';
export declare function sleep(msec: number): Promise<unknown>;
declare const type = "remote";
/**
 * Clone
 *
 * @throws {@link Err.CannotConnectError}
 * @throws {@link Err.CannotCloneRepositoryError}
 */
declare function clone(workingDir: string, remoteOptions: RemoteOptions, logger?: Logger): Promise<void>;
/**
 * Check connection by FETCH
 *
 * @throws {@link Err.InvalidURLError}
 * @throws {@link Err.RemoteRepositoryNotFoundError}
 * @throws Error (Other errors from NodeGit.Remote#connect())
 *
 * @internal
 */
declare function checkFetch(workingDir: string, options: RemoteOptions, credentialCallbacks: {
    [key: string]: any;
}, logger?: Logger): Promise<'exist' | 'not_exist'>;
/**
 * Check connection by PUSH
 *
 * @throws {@link Err.InvalidURLError}
 * @throws {@link Err.RemoteRepositoryNotFoundError}
 * @throws {@link Err.PushPermissionDeniedError}
 * @throws Error (Other errors from NodeGit.Remote#connect())
 *
 * @internal
 */
declare function checkPush(workingDir: string, options: RemoteOptions, credentialCallbacks: {
    [key: string]: any;
}, logger?: Logger): Promise<string>;
export { checkFetch, checkPush, clone, type };
//# sourceMappingURL=remote-nodegit.d.ts.map